@@ -67,6 +67,24 @@ typedef struct {
     GtkApplicationClass parent_class;
 } FontViewApplicationClass;
 
+static gboolean
+_print_version_and_exit (const gchar *option_name,
+                         const gchar *value,
+                         gpointer data,
+                         GError **error)
+{
+    g_print("%s %s\n", _("GNOME Font Viewer"), VERSION);
+    exit (EXIT_SUCCESS);
+    return TRUE;
+}
+
+static const GOptionEntry goption_options[] =
+{
+    { "version", 0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
+      _print_version_and_exit, N_("Show the application's version"), NULL},
+    { NULL }
+};
+
 G_DEFINE_TYPE (FontViewApplication, font_view_application, GTK_TYPE_APPLICATION);
 
 static void font_view_application_do_overview (FontViewApplication *self);
@@ -135,20 +153,22 @@ strip_version (gchar **original)
 
 static void
 add_row (GtkWidget *grid,
-	 const gchar *name,
-	 const gchar *value,
-	 gboolean multiline)
+         const gchar *name,
+         const gchar *value,
+         gboolean multiline)
 {
     GtkWidget *name_w, *label;
 
     name_w = gtk_label_new (name);
     gtk_style_context_add_class (gtk_widget_get_style_context (name_w), "dim-label");
-    gtk_misc_set_alignment (GTK_MISC (name_w), 1.0, 0.0);
+    gtk_widget_set_halign (name_w, GTK_ALIGN_END);
+    gtk_widget_set_valign (name_w, GTK_ALIGN_START);
 
     gtk_container_add (GTK_CONTAINER (grid), name_w);
 
     label = gtk_label_new (value);
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_START);
     gtk_label_set_selectable (GTK_LABEL(label), TRUE);
 
     gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
@@ -167,7 +187,7 @@ add_row (GtkWidget *grid,
 static void
 populate_grid (FontViewApplication *self,
                GtkWidget *grid,
-	       FT_Face face)
+               FT_Face face)
 {
     gchar *s;
     GFileInfo *info;
@@ -465,8 +485,8 @@ info_button_clicked_cb (GtkButton *button,
     gtk_orientable_set_orientation (GTK_ORIENTABLE (grid), GTK_ORIENTATION_VERTICAL);
     g_object_set (grid,
                   "margin-top", 6,
-                  "margin-left", 16,
-                  "margin-right", 16,
+                  "margin-start", 16,
+                  "margin-end", 16,
                   "margin-bottom", 6,
                   NULL);
     gtk_grid_set_column_spacing (GTK_GRID (grid), 8);
@@ -890,6 +910,8 @@ main (int argc,
 {
     GApplication *app;
     gint retval;
+    GError *error = NULL;
+    GOptionContext *ctx;
 
     bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -898,6 +920,26 @@ main (int argc,
     if (!FcInit ())
         g_critical ("Can't initialize fontconfig library");
 
+    ctx = g_option_context_new (_("[FILE...]"));
+    g_option_context_add_main_entries (ctx, goption_options, PACKAGE);
+    g_option_context_add_group (ctx, gtk_get_option_group (FALSE));
+
+    if (!g_option_context_parse (ctx, &argc, &argv, &error)) {
+        gchar *help_msg;
+
+        /* I18N: The '%s' is replaced with the command name. */
+        help_msg = g_strdup_printf (_("Run '%s --help' to see a full "
+                                      "list of available command line "
+                                      "options."), argv[0]);
+        g_printerr ("%s\n%s\n", error->message, help_msg);
+        g_error_free (error);
+        g_free (help_msg);
+        g_option_context_free (ctx);
+
+        return EXIT_FAILURE;
+    }
+    g_option_context_free (ctx);
+
     app = font_view_application_new ();
     retval = g_application_run (app, argc, argv);
 
